InformationUnit

Enum InformationUnit 

pub enum InformationUnit {
Show 14 variants Bit, Byte, KiloByte, KibiByte, MegaByte, MebiByte, GigaByte, GibiByte, TeraByte, TebiByte, PetaByte, PebiByte, ExaByte, ExbiByte,
}
Size of information derived from bytes, used in MetricUnit::Information.

Defaults to byte. See also Units of information.

Variants



Bit

Bit ("bit"), corresponding to 1/8 of a byte.

Note that there are computer systems with a different number of bits per byte.



Byte

Byte ("byte").



KiloByte

Kilobyte ("kilobyte"), 10^3 bytes.



KibiByte

Kibibyte ("kibibyte"), 2^10 bytes.



MegaByte

Megabyte ("megabyte"), 10^6 bytes.



MebiByte

Mebibyte ("mebibyte"), 2^20 bytes.



GigaByte

Gigabyte ("gigabyte"), 10^9 bytes.



GibiByte

Gibibyte ("gibibyte"), 2^30 bytes.



TeraByte

Terabyte ("terabyte"), 10^12 bytes.



TebiByte

Tebibyte ("tebibyte"), 2^40 bytes.



PetaByte

Petabyte ("petabyte"), 10^15 bytes.



PebiByte

Pebibyte ("pebibyte"), 2^50 bytes.



ExaByte

Exabyte ("exabyte"), 10^18 bytes.



ExbiByte

Exbibyte ("exbibyte"), 2^60 bytes.

Implementations

Source

impl InformationUnit

pub fn as_str(&self) -> &'static str

Returns the string representation for this information unit.